#!/bin/bash

if [ -n "$PBS_JOBID" ]; then
	export QCG_APP_SYSTEM_TYPE="torque"
	export QCG_APP_LOCAL_JOB_ID="$PBS_JOBID"
elif [ -n "$SLURM_JOB_ID" ]; then
	export QCG_APP_SYSTEM_TYPE="slurm"
	export QCG_APP_LOCAL_JOB_ID="$SLURM_JOB_ID"
fi


export QCG_APP_ROOT_DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"/..

#echo "system [$QCG_APP_SYSTEM_TYPE]"
#echo "local id [$QCG_APP_LOCAL_JOB_ID]"
#echo "root dir [$QCG_APP_ROOT_DIR]"

#source common config
if [ -f $QCG_APP_ROOT_DIR/config/config.conf ]; then
    . $QCG_APP_ROOT_DIR/config/config.conf
fi

function qcg_app_resource_memory_mbytes() {
	local default=$1
	local MEM_BYTES
	local MEM_MBYTES
	local PER_CORE=1

	case "$QCG_APP_SYSTEM_TYPE" in
		"torque")
			MEM_BYTES=`qstat -f $PBS_JOBID | grep Resource_List.mem | cut -f 2 -d = | tr "b" " " `

			if [ "x$MEM_BYTES" == "x" ]; then
				MEM_BYTES=`qstat -f $PBS_JOBID | grep Resource_List.pmem | cut -f 2 -d = | tr "b" " " `
				PER_CORE=$QCG_PROCS
			else
				PER_CORE=1
			fi

			if [ "x$MEM_BYTES" != "x" ]; then
				if [ `echo $MEM_BYTES | grep k | wc -l ` -eq 1 ]; then
					MEM_BYTES=`echo $MEM_BYTES | tr -d "k"`
					MEM_MBYTES=$(($MEM_BYTES / 1024))
				elif [ `echo $MEM_BYTES | grep m | wc -l ` -eq 1 ]; then
					MEM_BYTES=`echo $MEM_BYTES | tr -d "m"`
					MEM_MBYTES=$MEM_BYTES
				else
					MEM_MBYTES=$(($MEM_BYTES / 1024 / 1024))
				fi

				MEM_MBYTES=$(($MEM_MBYTES * $PER_CORE))
			fi

			;;
		"slurm")
			if [ "$SLURM_MEM_PER_CPU" ]; then
		    	MEM_BYTES=$(($SLURM_CPUS_ON_NODE * $SLURM_MEM_PER_CPU  * 1048576))
			else
			    MEM_BYTES=$(($SLURM_MEM_PER_NODE  * 1048576))
			fi
			MEM_MBYTES=$(($MEM_BYTES / 1024 / 1024))
			;;
#		*)
#			echo "unknown local system type"
#			exit 1
	esac

	if [ "x$MEM_MBYTES" == "x" ]; then
		MEM_MBYTES="$default"
	fi

	echo "$MEM_MBYTES"
}
