#!/bin/bash

### temporary files

FILES_MOD_TIME=.qcg.mon_mod_time
FILES_NUMBERED=.qcg.mon_num


### auxiliary functions ###


images_get_history_last_mod_file() {
	local file=$1

	if [ -f "$FILES_MOD_TIME" ]; then
		local result=`awk "/^$file/ { print \\$2 }" "$FILES_MOD_TIME"`
#		echo "found previous last mod file [$result]"
		[ -z "$result" ] && result="0"
		echo "$result"
	else
		echo "0"
	fi
}


images_put_history_last_mod_file() {
	local file=$1
	local last_mod=$2

	if [ -f "$FILES_MOD_TIME" ]; then
		local result=`awk "/^$file/ { print \$2 }" "$FILES_MOD_TIME"`

#		echo "$file history result [$result], tmp file [$FILES_MOD_TIME]"

		if [ -z "$result" ]; then
#			echo "$file doesn't exists in history"
			echo "$file $last_mod" >> $FILES_MOD_TIME
		else
#			echo "$file exists in history"
			sed -i "s/^$file.*$/$file $last_mod/" "$FILES_MOD_TIME"
		fi
	else
		echo "$file $last_mod" > $FILES_MOD_TIME
	fi
}


### images handles functions ###


###############################################################################
#
# Return those images that has been modified from last function call.
# 
# Arguments:
#		- list of image names or file pattern
#
# Returns:
#		- list of image paths that has been changed from last function call.
#
###############################################################################
images_get_changed() {
	local img_names=$1
	local result=""

	for file in $IMG_NAMES; do
#		echo -n "img [$file]: "
		last_mod=`stat -c %Y $file`
#		echo -n "lastmod [$last_mod]"
		prev_last_mod=`images_get_history_last_mod_file "$file"`

#		echo ", prev lastmod [$prev_last_mod]"

		if [ "$last_mod" -ne "$prev_last_mod" ]; then 
#			echo "$file MODIFIED"
			images_put_history_last_mod_file "$file" "$last_mod"

			result="$result $file"
		fi
	done

	echo $result
}


###############################################################################
#
# Return new images with number pattern that were created with higher numbers.
# 
# Arguments:
#		- image file pattern
#		- number of new images to return (optional)
#
# Returns:
#		- list of new images
#
###############################################################################
images_numbered_get_last() {
	local img_tmpl=$1
	local length=$2

	local pattern=`echo $img_tmpl | sed 's/#X#/\[0-9\]/g'`
#	echo "pattern [$pattern]"

	local files=`ls $pattern`

	local last_file=""
	
	if [ -f "$FILES_NUMBERED" ]; then
		last_file=`cat $FILES_NUMBERED`
	fi

	if [ "x$last_file" != "x" ]; then
		local last_file_conv=`echo "$last_file" | sed 's@/@\\\/@g'`
#		echo "filtering from [$last_file_conv] ..."
		files=`echo "$files" | awk "BEGIN { off=0; curr=0 } /$last_file_conv/ { off=1 } { if (curr == 1) print; if (off == 1) { off=0; curr=1 } }"`
#		echo "after filter [$files]"
	fi

#	echo "files [$files]"
	local last_pos=`echo "$files" | tail -n 1`
	if [ "x$last_pos" != "x" ]; then
		echo "$last_pos" > $FILES_NUMBERED
	fi

	if [ "x$length" != "x" ]; then
		files=`echo "$files" | tail -n $length`
	fi

#	for file in $files; do
#		echo "file [$file]"
#	done

	echo $files
}
