#!/bin/bash


function first_pbs_job_status() {
	local jobinfo=`qstat -f $PBS_JOBID`
	local result=`echo "$jobinfo" | awk '
BEGIN { first=1 }
/^Job Id:/ 			{ if (! first) { print "," } printf "\"jobid\": \"%s\"", $3; first=0 }
/^[ \t]*resources_used.cput/	{ if (! first) { print "," } printf "\"cpu time\": \"%s\"", $3; first=0 }
/^[ \t]*resources_used.mem/	{ if (! first) { print "," } printf "\"memory\": \"%s\"", $3; first=0 }
/^[ \t]*resources_used.walltime/{ if (! first) { print "," } printf "\"walltime\": \"%s\"", $3; first=0 }
/^[ \t]*queue/			{ if (! first) { print "," } printf "\"queue\": \"%s\"", $3; first=0 }
/^[ \t]*Account_Name/		{ if (! first) { print "," } printf "\"grant\": \"%s\"", $3; first=0 }
/^[ \t]*start_time/		{ if (! first) { print "," } printf "\"started\": \"%s", $3; for (i=4; i < NF; ++i) printf " %s", $i; printf "\""; first=0 }'`

	if [ -n "$PBS_NUM_NODES" ]; then
		[ -n "$result" ] && result="$result,"$'\n'
		result="$result\"nodes\": \"$PBS_NUM_NODES\""
	fi

	if [ -n "$PBS_NP" ]; then
		[ -n "$result" ] && result="$result,"$'\n'
		result="$result\"cores\": \"$PBS_NP\""
	fi

	if [ -n "$PBS_NUM_PPN" ]; then
		[ -n "$result" ] && result="$result,"$'\n'
		result="$result\"cores/node\": \"$PBS_NUM_PPN\""
	fi

	[ -n "$result" ] && result="$result,"$'\n'
	result="$result\"master node\": \"$HOSTNAME\""

	if hash qnodes >/dev/null 2>&1; then
		local nodeinfo=`qnodes $HOSTNAME`
		local nresult=`echo "$nodeinfo" | awk '
BEGIN { first=1 }
/^[ \t]*np/			{ if (! first) { print "," } printf "\"node cores\": \"%s\"", $3; first=0 }
/^[ \t]*properties/		{ if (! first) { print "," } printf "\"node properties\": \"%s\"", $3; first=0 }'`
		if [ -n "$nresult" ]; then
			[ -n "$result" ] && result="$result,"$'\n'
			result="${result}${nresult}"
		fi
	fi

	[ -n "$result" ] && QCG_MONITOR_SECTION_JOB="$result"
}


function first_slurm_job_status() {
	local jobinfo=`scontrol -d show job $SLURM_JOB_ID`
	local result=`echo "$jobinfo" | awk -v RS="[ \n]+" -v FS="="  '
BEGIN { first=1 }
/\<RunTime\>/	{ if (! first) { print "," } printf "\"walltime\": \"%s\"", $2; first=0 }
/\<StartTime\>/	{ if (! first) { print "," } printf "\"started\": \"%s\"", $2; first=0 }
/\<Partition\>/	{ if (! first) { print "," } printf "\"queue\": \"%s\"", $2; first=0 }
/\<NodeList\>/	{ if (! first) { print "," } printf "\"nodes list\": \"%s\"", $2; first=0 }
/\<NumNodes\>/	{ if (! first) { print "," } printf "\"nodes\": \"%s\"", $2; first=0 }
/\<NumCPUs\>/	{ if (! first) { print "," } printf "\"cores\": \"%s\"", $2; first=0 }'`

	if [ -n "$QCG_HOST" ]; then
		[ -n "$result" ] && result="$result,"$'\n'
		result="$result\"cluster\": \"$QCG_HOST\""
	fi

	if [ -n "$QCG_NOTE" ]; then
		[ -n "$result" ] && result="$result,"$'\n'
		result="$result\"note\": \"$QCG_NOTE\""
	fi

	[ -n "$result" ] && result="$result,"$'\n'
	result="$result\"master node\": \"$HOSTNAME\""

	local nodeinfo=`scontrol -d show node $HOSTNAME`
	local nresult=`echo "$nodeinfo" | awk -v RS="[ \n]+" -v FS="="  '
BEGIN { first=1 }
/\<Arch\>/		{ if (! first) { print "," } printf "\"node arch\": \"%s\"", $2; first=0 }
/\<CPUTot\>/	{ if (! first) { print "," } printf "\"node cores\": \"%s\"", $2; first=0 }
/\<Features\>/	{ if (! first) { print "," } printf "\"node properties\": \"%s\"", $2; first=0 }
/\<OS\>/		{ if (! first) { print "," } printf "\"node os\": \"%s\"", $2; first=0 }
/\<RealMemory\>/{ if (! first) { print "," } printf "\"node memory\": \"%s\"", $2; first=0 }'`
	if [ -n "$nresult" ]; then
		[ -n "$result" ] && result="$result,"$'\n'
		result="${result}${nresult}"
	fi

	[ -n "$result" ] && QCG_MONITOR_SECTION_JOB="$result"
}


function job_status() {
	if [ -n "$PBS_JOBID" ]; then
		first_pbs_job_status
	elif [ -n "$SLURM_JOB_ID" ]; then
		first_slurm_job_status
	fi
}


job_status
