#!/bin/bash

######

# Assign variable one scope above the caller
# Usage: local "$1" && upvar $1 "value(s)"
# Param: $1  Variable name to assign value to
# Param: $*  Value(s) to assign.  If multiple values, an array is
#            assigned, otherwise a single value is assigned.
# NOTE: For assigning multiple variables, use 'upvars'.  Do NOT
#       use multiple 'upvar' calls, since one 'upvar' call might
#       reassign a variable to be used by another 'upvar' call.
# Example: 
#
#    f() { local b; g b; echo $b; }
#    g() { local "$1" && upvar $1 bar; }
#    f  # Ok: b=bar
#
upvar() {
    if unset -v "$1"; then           # Unset & validate varname
        if (( $# == 2 )); then
            eval $1=\"\$2\"          # Return single value
        else
            eval $1=\(\"\${@:2}\"\)  # Return array
        fi
    fi
}

######


function append_section_map_item {
    local varname=$1
    local varvalue="$2"
    local name="$3"
    local value="$4"

    [ -n "$varvalue" ] && varvalue="$varvalue,"$'\n'
    varvalue="${varvalue}\"${name}\": \"${value}\""

    local $varname && upvar $varname "$varvalue"
}


function append_section_item {
    local varname=$1
    local varvalue="$2"
    local value="$3"

    [ -n "$varvalue" ] && varvalue="$varvalue,"$'\n'
    varvalue="${varvalue}\"${value}\""

    local $varname && upvar $varname "$varvalue"
}


function append_section_numeric_item {
    local varname=$1
    local varvalue="$2"
    local value="$3"

    [ -n "$varvalue" ] && varvalue="$varvalue,"$'\n'
    varvalue="${varvalue}${value}"

    local $varname && upvar $varname "$varvalue"
}


function append_array_section {
    local varname=$1
    local varvalue="$2"
    local arrname="$3"
    local arrvalue="$4"

    [ -n "$varvalue" ] && varvalue="$varvalue,"$'\n'
    varvalue="${varvalue}\"${arrname}\": [ ${arrvalue} ]"

    local $varname && upvar $varname "$varvalue"
}



function append_job {
	append_section_map_item QCG_MONITOR_SECTION_JOB "$QCG_MONITOR_SECTION_JOB" "$1" "$2"
}


function append_status {
	append_section_map_item QCG_MONITOR_SECTION_STATUS "$QCG_MONITOR_SECTION_STATUS" "$1" "$2"
}


function append_option {
	append_section_map_item QCG_MONITOR_SECTION_OPTIONS "$QCG_MONITOR_SECTION_OPTIONS" "$1" "$2"
}


function append_text {
	append_section_item QCG_MONITOR_SECTION_TEXT "$QCG_MONITOR_SECTION_TEXT" "$1"
}


function append_sections {
	append_section_numeric_item QCG_MONITOR_SECTIONS_OTHER "$QCG_MONITOR_SECTIONS_OTHER" "$1"
}

