#include <stdarg.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>

#include "debug.h"


/*****************************************************************************/


static FILE *log_output = NULL;
static int log_level = 0;


/*****************************************************************************/


void log_set_output(FILE *out) {
	log_output = out;
}


void log_set_level(int level) {
	log_level = level;
}


void log_print_debug(int level, const char *format, ...) {
	static char buffer[1024];
	va_list ap;

	if (level < log_level)
		return;

	va_start(ap, format);

	vsnprintf(buffer, sizeof(buffer), format, ap);

	va_end(ap);

	strncat(buffer, "\n", sizeof(buffer));

	if (level > L_INFO) {
		fputs(buffer, stderr);
		fflush(stderr);
	}

	if (log_output) {
		fputs(buffer, log_output);
		fflush(log_output);
	}
}


void log_print_errno_exit(const char *format, ...) {
	static char buffer[1024];
	va_list ap;

	snprintf(buffer, sizeof(buffer), "ERROR(%d:%s)", errno, strerror(errno));

	fputs(buffer, stderr);

	if (log_output)
		fputs(buffer, log_output);

	va_start(ap, format);
	vsnprintf(buffer, sizeof(buffer), format, ap);
	va_end(ap);

	strncat(buffer, "\n", sizeof(buffer));

	fputs(buffer, stderr);
	if (log_output)
		fputs(buffer, log_output);

	fflush(stderr);
	fflush(log_output);

	exit(1);
}



/*****************************************************************************/
