#include <string.h>
#include <unistd.h>

#include <sys/types.h>
#include <sys/socket.h>
#include <netdb.h>
#include <netinet/in.h>
#include <netinet/tcp.h>

#include "socket_util.h"
#include "debug.h"


/*****************************************************************************/


int connectTo(const char *host, const char *port) {
	int sock, res;
	struct addrinfo hints;
	struct addrinfo *result, *rp;
	char c_host[128], c_service[128];
	int tcp_nodelay;

	sock = socket(AF_INET, SOCK_STREAM, 0);
	if (sock == -1) {
		LOG(L_ERROR, "failed to create socket");
		return -1;
	}

	/* TCP_NODELAY */
	tcp_nodelay = 1;
	if ((setsockopt(sock, IPPROTO_TCP, TCP_NODELAY, (char*)&tcp_nodelay,
					sizeof(int))))
		LOG(L_WARN, "warning: failed to set TCP_NODELAY");

	memset(&hints, 0, sizeof(struct addrinfo));
	hints.ai_family = AF_INET;
	hints.ai_socktype = SOCK_STREAM;
	hints.ai_flags = 0;
	hints.ai_protocol = 0;
	res = getaddrinfo(host, port, &hints, &result);

	if (res != 0) {
		LOG(L_ERROR, "failed to get address for host (%s:%s): %s", host, port, gai_strerror(res));
		close(sock);
		return -1;
	}

	for (rp = result; rp != NULL; rp = rp->ai_next) {
		getnameinfo((struct sockaddr*)rp->ai_addr, sizeof(struct sockaddr),
				c_host, sizeof(c_host), c_service, sizeof(c_service),
				NI_NUMERICSERV);

		LOG(L_DEBUG, "trying to connect to %s:%s", c_host, c_service);

		sock = socket(rp->ai_family, rp->ai_socktype, rp->ai_protocol);
		if (sock == -1)
			continue;

		if (connect(sock, rp->ai_addr, rp->ai_addrlen) != -1) {
			LOG(L_DEBUG, "connection established");
			break;
		}

		close(sock);
	}

	if (rp == NULL) {
		LOG(L_ERROR, "failed to connect");
		return -1;
	}

	freeaddrinfo(result);
	return sock;
}


void closeSocket(int sock) {
	close(sock);
}


/*****************************************************************************/
